Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(285)

Unified Diff: components/arc/instance_holder.h

Issue 2619843002: arc: rename GetInstanceForVersion (Closed)
Patch Set: fix comment Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/arc/instance_holder.h
diff --git a/components/arc/instance_holder.h b/components/arc/instance_holder.h
index 4918cd2d5616cce7790630b621b2d960f8d9ee06..fda056e646139fb48e8dc8e2773598b2ebc8ae53 100644
--- a/components/arc/instance_holder.h
+++ b/components/arc/instance_holder.h
@@ -14,12 +14,12 @@
#include "base/observer_list.h"
#include "base/threading/thread_checker.h"
// A convenience macro to call arc::InstanceHolder<T>::GetInstanceForVersion().
// In order to avoid exposing method names from within the Mojo bindings, we
// will rely on stringification and the fact that the method min versions have a
// consistent naming scheme.
#define ARC_GET_INSTANCE_FOR_METHOD(holder, method_name) \
- (holder)->GetInstanceForVersion( \
+ (holder)->GetInstanceForVersionDoNotCallDirectly( \
std::remove_pointer<decltype( \
holder)>::type::Instance::k##method_name##MinVersion, \
#method_name)
@@ -60,8 +60,9 @@ class InstanceHolder {
// not have the requested version, and logs appropriately.
// This function should not be called directly. Instead, use the
// ARC_GET_INSTANCE_FOR_METHOD() macro.
- T* GetInstanceForVersion(uint32_t min_version,
- const char method_name_for_logging[]) {
+ T* GetInstanceForVersionDoNotCallDirectly(
+ uint32_t min_version,
+ const char method_name_for_logging[]) {
if (!instance_) {
VLOG(1) << "Instance for " << T::Name_ << "::" << method_name_for_logging
<< " not available.";
@@ -14,12 +14,12 @@
#include "base/observer_list.h"
#include "base/threading/thread_checker.h"
-// A convenience macro to call arc::InstanceHolder<T>::GetInstanceForVersion().
+// A macro to call InstanceHolder<T>::GetInstanceForVersionDoNotCallDirectly().
// In order to avoid exposing method names from within the Mojo bindings, we
// will rely on stringification and the fact that the method min versions have a
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698